@@ -1,7 +1,6 @@
 'use babel'
 import React from 'react'
 import ref from 'ssb-ref'
-import { rainbow } from '../index'
 import MDLSpinner from '../mdl-spinner'
 import { InviteErrorExplanation, InviteErrorHelp } from '../help/forms'
 import app from '../../lib/app'
@@ -24,25 +23,6 @@ export default class PubInvite extends React.Component {
   componentDidMount() {
     this.props.setIsReady(true)
     this.props.setIsValid(true)
-    this.props.setHelpText(<div className="faq">
-      { this.props.gotoNextStep ?
-        <div><a onClick={this.props.gotoNextStep}>You can skip this step</a>, but your messages {"won't"} reach outside the WiFi until you do it.</div>
-        : '' }
-      <div className="well">
-        <div className="faq-entry">
-          <strong>Can I become a Public Peer?</strong><br/>
-          Yes, but it requires a public IP address. If you have one, you can <a href="https://github.com/ssbc/docs#setup-up-a-pub" target="_blank">follow&nbsp;this&nbsp;guide</a>.
-        </div>
-        <div className="faq-entry">
-          <strong>{"What's"} an invite code?</strong><br/>
-          Invite codes tell a Public Peer to follow you socially, so {"they'll"} have your messages.
-        </div>
-        <div className="faq-entry">
-          <strong>Where can I get an invite code?</strong><br/>
-          Come to #scuttlebutt on Freenode and ask for one.
-        </div>
-      </div>
-    </div>)
   }
 
   getValues(cb) {
@@ -86,8 +66,8 @@ export default class PubInvite extends React.Component {
     const helpText = (this.state.error) ? <InviteErrorHelp error={this.state.error} /> : ''
 
     return <div>
-      <h1>Connect with {rainbow('Public Peers')}</h1>
-      <h3>Public Peers host your messages online.</h3>
+      <h1>Join a Pub</h1>
+      <h3>Pubs host your messages online, and connect you globally.</h3>
       <form className="fullwidth" onSubmit={e=>e.preventDefault()}>
         <fieldset>
           <input type="text" value={this.state.code} onChange={this.onChange.bind(this)} placeholder="Enter the invite code here" />
@@ -96,6 +76,23 @@ export default class PubInvite extends React.Component {
         </fieldset>
       </form>
       { this.state.isProcessing ? <MDLSpinner /> : '' }
+      <div className="faq text-center">
+        { this.props.gotoNextStep ?
+          <div><a onClick={this.props.gotoNextStep}>You can skip this step</a>, but your messages {"won't"} reach outside the WiFi until you do it.</div>
+          : '' }
+        <div className="faq-entry">
+          <div>{"What's"} an invite code?</div>
+          <div>An invite code tells the Pub to join your contacts.</div>
+        </div>
+        <div className="faq-entry">
+          <div>Where can I get an invite code?</div>
+          <div>You should ask a Pub operator. Many of them hang out in #scuttlebutt on Freenode.</div>
+        </div>
+        <div className="faq-entry">
+          <div>Can I create a Pub?</div>
+          <div>Yes, but it requires a public server. If you have one, you can <a href="http://ssbc.github.io/docs/scuttlebot/howto-setup-a-pub.html" target="_blank">follow&nbsp;this&nbsp;guide</a>.</div>
+        </div>
+      </div>
     </div>
   }
 }
\ No newline at end of file
