@@ -1,6 +1,6 @@
 'use babel'
 import React from 'react'
-import markdown from '../lib/markdown'
+import markdown from 'ssb-markdown'
 
 export class Block extends React.Component {
   render() {
@@ -11,4 +11,4 @@ export class Inline extends React.Component {
   render() {
     return <span className="markdown markdown-inline" dangerouslySetInnerHTML={{__html: markdown.inline(this.props.md)}} />
   }
-}
\ No newline at end of file
+}
