@@ -184,9 +184,8 @@ export default class Card extends React.Component {
   }
 
   renderLink(msg) {
-    const name = u.shortString(msg.value ? (msg.value.content.text || msg.key) : msg.key, 100)
     return <div key={msg.key} className="msg-view card-missing-post">
-      <div><i className="fa fa-angle-up" /> <MsgLink id={msg.key} name={name} /></div>
+      <div><i className="fa fa-angle-double-up" /> <MsgLink id={msg.key} name="View the full discussion" /></div>
     </div>
   }
 
@@ -246,7 +245,7 @@ export default class Card extends React.Component {
       <div className="content">
         <div className="header">
           <div className="header-left">
-            <UserLink id={msg.value.author} /> <span className="date"><NiceDate ts={msg.value.timestamp} /></span>
+            <UserLink id={msg.value.author} /> <Link className="date" to={'/msg/'+encodeURIComponent(msg.key)}><NiceDate ts={msg.value.timestamp} /></Link>
           </div>
           <div className="header-right">
             { !this.props.noBookmark ? <BookmarkBtn isBookmarked={msg.isBookmarked} onClick={()=>this.props.onToggleBookmark(msg)} /> : '' }
