@@ -19,7 +19,7 @@ class SearchResults extends React.Component {
     }
   }
 
-  onMouseOverResult(index) {
+  onMouseEnterResult(index) {
     this.setState({ selected: index })
   }
 
@@ -40,8 +40,9 @@ class SearchResults extends React.Component {
   }
 
   render() {
+    const onClickResult = this.props.onClickResult
     const Result = props => {
-      return <div className={cls({ selected: this.state.selected === props.index })} onMouseOver={this.onMouseOverResult.bind(this, props.index)} onClick={this.props.onClickResult}>
+      return <div className={cls({ selected: this.state.selected === props.index })} onMouseEnter={this.onMouseEnterResult.bind(this, props.index)} onClick={onClickResult}>
         <i className={'fa fa-'+props.icon} /> {props.label}
       </div>
     }
@@ -73,6 +74,7 @@ export default class SearchPalette extends React.Component {
     // update query & results
     const query = e.target.value
     this.setState({
+      isOpen: true,
       query: query,
       results: (query) ? getResults(query) : []
     })
@@ -109,13 +111,14 @@ export default class SearchPalette extends React.Component {
 
   render() {
     return <div className="search-palette">
-      <i className="fa fa-search" />
+      <i className="fa fa-search" onClick={this.focus.bind(this)} />
       <input 
         ref="search"
         value={this.state.query}
+        placeholder={this.props.placeholder||'Search your inbox'}
         onChange={this.onChange.bind(this)}
         onKeyDown={this.onKeyDown.bind(this)} />
-      { this.state.isOpen ? <SearchResults ref="results" query={this.state.query} results={this.state.results} onClickResult={this.onSearch.bind(this)} /> : '' }
+      { this.state.isOpen && !!this.state.query ? <SearchResults ref="results" query={this.state.query} results={this.state.results} onClickResult={this.onSearch.bind(this)} /> : '' }
     </div>
   }
 }
\ No newline at end of file
