@@ -11,7 +11,11 @@ export default class TopNav extends React.Component {
     this.state = { isComposerOpen: false }
 
     // listen for events that should update our state
-    app.on('focus:search', this.focusSearch.bind(this))
+    this._focusSearch = this.focusSearch.bind(this)
+    app.on('focus:search', this._focusSearch)
+  }
+  componentWillUnmount() {
+    app.removeListener('focus:search', this._focusSearch)
   }
 
   focusSearch() {
@@ -48,18 +52,16 @@ export default class TopNav extends React.Component {
     const onClickCompose = this.onClickCompose.bind(this)
     return <div className="topnav">
       <div className="flex topnav-bar">
-        <div className="flex-fill"><SearchPalette ref="search" query={this.props.searchQuery} /></div>
-        { this.state.isComposerOpen
-          ? <a className="compose-btn cancel" onClick={onClickCompose}><i className="fa fa-times" /> Cancel</a>
-          : <a className="compose-btn" onClick={onClickCompose}><i className="fa fa-plus" /> New Post</a> }
+        <div className="flex-fill"><SearchPalette ref="search" query={this.props.searchQuery} placeholder={this.props.placeholder} /></div>
+        { this.props.composer
+          ? ( this.state.isComposerOpen
+            ? <a className="btn" onClick={onClickCompose}><i className="fa fa-times" /> Cancel</a>
+            : <a className="btn highlighted" onClick={onClickCompose}><i className="fa fa-plus" /> Compose</a> )
+          : '' }
       </div>
-      <div className="flex topnav-content">
-        { (this.props.contentTypes||[]).map((ct, i) => {
-          var cls = classNames({ selected: i===0 }) // TODO
-          return <a key={ct} className={cls}>{ct}</a>
-        }) }
-      </div>
-      { this.state.isComposerOpen ? <div ref="composer"><Composer {...this.props.composerProps} onSend={this.onSend.bind(this)} /></div> : '' }
+      { this.state.isComposerOpen && this.props.composer
+        ? <div ref="composer" className="topnav-composer"><Composer {...this.props.composerProps} onSend={this.onSend.bind(this)} /></div>
+        : '' }
     </div>
   }
 }
\ No newline at end of file
