@@ -2,8 +2,9 @@ var mlib = require('ssb-msgs')
 var ssbref = require('ssb-ref')
 var app = require('./app')
 
-var mentionRegex = 
-exports.regex = /([^A-z0-9_\-\/:]|^)([@%&](amp;)?[A-z0-9\._\-+=\/]*[A-z0-9_\-+=\/])/g
+var _mentionRegex = function() { return /([^A-z0-9_\-\/:]|^)([@%&](amp;)?[A-z0-9\._\-+=\/]*[A-z0-9_\-+=\/])/g }
+var _httpURLRegex = function() { return /https?:\/\/[^\s<]+[^<.,:;"')\]\s]/gi } // stolen from marked
+var _hostRegex = function() { return /https?\:\/\/([^\/?#]+)/gi }
 
 function shorten (hash) {
   return hash.slice(0, 8) + '..' + hash.slice(-11)
@@ -17,9 +18,10 @@ exports.extract = function (text, cb) {
     // collect any mentions
     var match
     var mentions = [], mentionedIds = {}
+    var mentionRegex = _mentionRegex()
     while ((match = mentionRegex.exec(text))) {
       var ref = match[2]
-      var name = ref.slice(1) // lose the @
+      var name = ref.slice(1) // lose the sigil
       var id = idsByName[name]
 
       // name conflict? abort
@@ -40,6 +42,25 @@ exports.extract = function (text, cb) {
       }
     }
 
+    // look for HTTP urls that point to messages, and which we can (therefore) turn into mentions
+    var httpURLRegex = _httpURLRegex()
+    while ((match = httpURLRegex.exec(text))) {
+      var href = match[0]
+      var id = ssbref.extract(href)
+      if (!id)
+        continue // not an ssb id
+
+      // already mentioned?
+      if (id in mentionedIds)
+        continue // skip
+
+      var m = { link: id, href: href }
+      var hostMatch = _hostRegex().exec(href) // try to extract host
+      if (hostMatch)
+        m.host = hostMatch[0]
+      mentionedIds[id] = mentions.push(m) - 1
+    }
+
     cb(null, mentions)
   })
 }
\ No newline at end of file
