@@ -3,23 +3,16 @@ var app = require('./app')
 
 var follows =
 exports.follows = function (a, b) {
-  var ap = app.users.profiles[a]
-  if (!ap) return false
-  return ap.assignedTo[b] && ap.assignedTo[b].following
+  var bp = app.users.profiles[b]
+  if (!bp) return false
+  return bp.followers[a]
 }
 
 var flags =
 exports.flags = function (a, b) {
-  var ap = app.users.profiles[a]
-  if (!ap) return false
-  return ap.assignedTo[b] && ap.assignedTo[b].flagged
-}
-
-var blocks =
-exports.blocks = function (a, b) {
-  var ap = app.users.profiles[a]
-  if (!ap) return false
-  return ap.assignedTo[b] && ap.assignedTo[b].blocking
+  var bp = app.users.profiles[b]
+  if (!bp) return false
+  return bp.flaggers[a]
 }
 
 var followeds =
@@ -34,12 +27,9 @@ exports.followeds = function (a) {
 
 var followers =
 exports.followers = function (b) {
-  var ids = []
-  for (var a in app.users.profiles) {
-    if (follows(a, b))
-      ids.push(a)
-  }
-  return ids
+  var bp = app.users.profiles[b]
+  if (!bp) return []
+  return Object.keys(bp.followers)
 }
 
 var followedFollowers =
